# Security Policy

## Supported Versions

The most recent major version will receive security updates. Older major
versions will be updated if backports are requested and are reasonable.

## Reporting a Vulnerability

To report a vulnerability, please raise an Issue or contact us directly. Fixed
vulnerabilities will result in a bugfix, minor, or major version release,
depending on what the fix requires.
